@@ -63,9 +63,25 @@ find_globals_liberal <- function(expr, envir, ..., trace = FALSE) {
 
 #' @importFrom codetools makeUsageCollector walkCode
 find_globals_ordered <- function(expr, envir, ..., trace = FALSE) {
+  selfassign <- getOption("globals.selfassign", TRUE)
+  
   class <- name <- character()
-
+  
   enter_local <- function(type, v, e, w) {
+    ## LH <- RH: Handle cases where a global variable exists in RH and LH
+    ##           assigns a local variable with the same name, e.g. x <- x + 1.
+    ##           In such case we want to detect 'x' as a global variable.
+    if (selfassign && type == "<-") {
+      rhs <- e[[3]]
+      globals <- all.names(rhs)
+      if (length(rhs) == 3 && globals[1] %in% c("::", ":::")) {
+        ## Case: a <- pkg::a
+      } else if (v %in% globals) {
+        class <<- c(class, "global")
+        name <<- c(name, v)
+      }
+    }
+
     class <<- c(class, "local")
     name <<- c(name, v)
   }
@@ -73,11 +89,11 @@ find_globals_ordered <- function(expr, envir, ..., trace = FALSE) {
   enter_global <- function(type, v, e, w) {
     class <<- c(class, "global")
     name <<- c(name, v)
-
+    
     ## Also walk formulas to identify globals
     if (type == "function") {
       if (v == "~") {
-        stopifnot(identical(e[[1]], as.symbol("~")))
+        stop_if_not(identical(e[[1]], as.symbol("~")))
         expr <- e[-1]
         for (kk in seq_along(expr)) {
           globals <- find_globals_ordered(expr = expr[[kk]], envir = w$env)
@@ -86,6 +102,21 @@ find_globals_ordered <- function(expr, envir, ..., trace = FALSE) {
             name <<- c(name, globals)
           }
         }
+      } else if (selfassign && v == "<-") {
+        ## LH <- RH: Handle cases where a global variable exists in LH in the
+        ##           form of x[1] <- 0, which will cause 'x' to be called a
+        ##           local variable later unless called global here.
+        lhs <- e[[2]]
+        if (length(lhs) >= 2) {
+          ## Cases: a[1] <- 0, names(a) <- "x", names(a)[1] <- "x"
+          ## Skip first symbol, because it'll be handled up later as
+          ## an assignment function, e.g. `[<-` and `names<-`
+          globals <- find_globals_ordered(expr = lhs, envir = w$env)
+          if (length(globals) > 0) {
+            class <<- c(class, rep("global", times = length(globals)))
+            name <<- c(name, globals)
+          }
+        }
       }
     }
   }
@@ -258,7 +289,10 @@ inject_tracer_to_function <- function(fcn, name) {
   title <- sprintf("%s():", name)
   b <- bquote({
     message(.(title))
-    if (length(.(args)) > 0) str(mget(.(args)))
+    if (length(.(args)) > 0) {
+      mstr <- get("mstr", envir = getNamespace("globals"), mode = "function")
+      mstr(mget(.(args)))
+    }
     .(b)
   })
   body(fcn) <- b
