@@ -13,7 +13,7 @@ packagesOf <- function(...) UseMethod("packagesOf")
 packagesOf.Globals <- function(globals, ...) {
   ## Scan 'globals' for which packages needs to be loaded.
   ## This information is in the environment name of the objects.
-  pkgs <- sapply(globals, FUN=function(obj) {
+  pkgs <- sapply(globals, FUN = function(obj) {
     environmentName(environment(obj))
   })
 
@@ -30,8 +30,7 @@ packagesOf.Globals <- function(globals, ...) {
   pkgs <- sort(unique(pkgs))
 
   ## Sanity check
-  stopifnot(all(nzchar(pkgs)))
+  stop_if_not(all(nzchar(pkgs)))
 
   pkgs
 } # packagesOf()
-
